==> pipewire_0.3.36.orig.tar.gz: pipewire-0.3.36/test/pwtest-compat.c <==
/* PipeWire
 *
 * Copyright © 2021 Red Hat, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include "config.h"

#if !HAVE_SIGABBREV_NP
#include <stddef.h>
#include <signal.h>

/* glibc >= 2.32 */
static inline const char *sigabbrev_np(int sig)
{
#define SIGABBREV(a_) case SIG##a_: return #a_
	switch(sig) {
	SIGABBREV(INT);
	SIGABBREV(ABRT);
	SIGABBREV(BUS);
	SIGABBREV(SEGV);
	SIGABBREV(ALRM);
	SIGABBREV(CHLD);
	SIGABBREV(HUP);
	SIGABBREV(PIPE);
	SIGABBREV(CONT);
	SIGABBREV(STOP);
	SIGABBREV(ILL);
	SIGABBREV(KILL);
	SIGABBREV(TERM);
	}
#undef SIGABBREV

	return NULL;
}

#endif /* HAVE_SIGABBREV_NP */

==> pipewire-0.3.58.tar.gz: pipewire-0.3.58/test/pwtest-compat.c <==
/* PipeWire
 *
 * Copyright © 2021 Red Hat, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include "config.h"

#ifndef HAVE_SIGABBREV_NP
#include <stddef.h>
#include <signal.h>

/* glibc >= 2.32 */
static inline const char *sigabbrev_np(int sig)
{
#define SIGABBREV(a_) case SIG##a_: return #a_
	switch(sig) {
	SIGABBREV(INT);
	SIGABBREV(ABRT);
	SIGABBREV(BUS);
	SIGABBREV(SEGV);
	SIGABBREV(ALRM);
	SIGABBREV(CHLD);
	SIGABBREV(HUP);
	SIGABBREV(PIPE);
	SIGABBREV(CONT);
	SIGABBREV(STOP);
	SIGABBREV(ILL);
	SIGABBREV(KILL);
	SIGABBREV(TERM);
	}
#undef SIGABBREV

	return NULL;
}

#endif /* HAVE_SIGABBREV_NP */
